==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/he.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "תצוגה מקדימה נטענת…",
    "Saved" : "נשמר",
    "Admin" : "ניהול",
    "a safe home for all your data" : "מקום בטוח לכל הנתונים שלך",
    "Name cannot be empty" : "השם לא יכול להישאר ריק",
    "The given name is too long" : "השם שסופק ארוך מדי",
    "The given web address is too long" : "הכתובת שסופקה ארוכה מדי",
    "The given legal notice address is too long" : "כתובת ההצהרה המשפטית שסופקה ארוכה מדי",
    "The given privacy policy address is too long" : "כתובת מדיניות הפרטיות שסופקה ארוכה מדי",
    "The given slogan is too long" : "שורת הכותרת שסופקה ארוכה מדי",
    "The given color is invalid" : "הצבע שסופק שגוי",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מהנחיית ה־upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שהוגדרה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי",
    "No file was uploaded" : "לא הועלו קבצים",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded" : "לא הועלה קובץ",
    "Unsupported image type" : "סוג התמונה לא נתמך",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "כבר נעשה שימוש בערכת עיצוב מותאמת אישית. יכול להיות שהגדרות יישומון ערכות העיצוב יידרסו.",
    "Theming" : "ערכות נושא",
    "Legal notice" : "הצהרה משפטית",
    "Privacy policy" : "מדיניות פרטיות",
    "Adjust the Nextcloud theme" : "התאמת ערכת העיצוב של Nextcloud",
    "Name" : "שם",
    "Reset to default" : "איפוס לבררת מחדל",
    "Web link" : "קישור",
    "https://…" : "https://…‎",
    "Slogan" : "שורת כותרת",
    "Color" : "צבע",
    "Logo" : "לוגו",
    "Upload new logo" : "העלאת לוגו חדש",
    "Login image" : "תמונת כניסה",
    "Upload new login background" : "העלאת תמונת כניסה חדשה",
    "Remove background image" : "הסרת תמונת רקע",
    "Advanced options" : "אפשרויות מתקדמות",
    "Legal notice link" : "קישור להצהרה המשפטית",
    "Privacy policy link" : "קישור למדיניות הפרטיות",
    "Header logo" : "לוגו כותרת",
    "Upload new header logo" : "העלאת לוגו כותרת",
    "reset to default" : "איפוס לבררת מחדל",
    "Web address" : "כתובת",
    "Web address https://…" : "כתובת https://…‎",
    "There is no error, the file uploaded with success" : "אין אף תקלה, הקובץ הועלה בהצלחה",
    "The uploaded file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "Failed to write file to disk." : "הכתיבה לכונן נכשלה.",
    "A PHP extension stopped the file upload." : "הרחבת PHP עצרה את העלאת הקובץ."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/he.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "תצוגה מקדימה נטענת…",
    "Saved" : "נשמר",
    "Admin" : "ניהול",
    "a safe home for all your data" : "מקום בטוח לכל הנתונים שלך",
    "Name cannot be empty" : "השם לא יכול להישאר ריק",
    "The given name is too long" : "השם שסופק ארוך מדי",
    "The given web address is too long" : "הכתובת שסופקה ארוכה מדי",
    "The given legal notice address is too long" : "כתובת ההצהרה המשפטית שסופקה ארוכה מדי",
    "The given privacy policy address is too long" : "כתובת מדיניות הפרטיות שסופקה ארוכה מדי",
    "The given slogan is too long" : "שורת הכותרת שסופקה ארוכה מדי",
    "The given color is invalid" : "הצבע שסופק שגוי",
    "The file was uploaded" : "הקובץ הועלה",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "הקובץ שהועלה חורג מהנחיית ה־upload_max_filesize ב־php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "הקובץ שהועלה חורג מההנחיה MAX_FILE_SIZE שהוגדרה בטופס ה־HTML",
    "The file was only partially uploaded" : "הקובץ הועלה באופן חלקי",
    "No file was uploaded" : "לא הועלו קבצים",
    "Missing a temporary folder" : "חסרה תיקייה זמנית",
    "Could not write file to disk" : "לא ניתן לכתוב לכונן",
    "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
    "No file uploaded" : "לא הועלה קובץ",
    "Unsupported image type" : "סוג התמונה לא נתמך",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "כבר נעשה שימוש בערכת עיצוב מותאמת אישית. יכול להיות שהגדרות יישומון ערכות העיצוב יידרסו.",
    "Theming" : "ערכות נושא",
    "Legal notice" : "הצהרה משפטית",
    "Privacy policy" : "מדיניות פרטיות",
    "Adjust the Nextcloud theme" : "התאמת ערכת העיצוב של Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "עם ערכות עיצוב ניתן להתאים את המראה והתחושה של המערכת ושל הלקוחות הנתמכים שלך. אלו תהיינה גלויות לכל המשתמשים.",
    "Name" : "שם",
    "Reset to default" : "איפוס לבררת מחדל",
    "Web link" : "קישור",
    "https://…" : "https://…‎",
    "Slogan" : "שורת כותרת",
    "Color" : "צבע",
    "Logo" : "לוגו",
    "Upload new logo" : "העלאת לוגו חדש",
    "Login image" : "תמונת כניסה",
    "Upload new login background" : "העלאת תמונת כניסה חדשה",
    "Remove background image" : "הסרת תמונת רקע",
    "Advanced options" : "אפשרויות מתקדמות",
    "Legal notice link" : "קישור להצהרה המשפטית",
    "Privacy policy link" : "קישור למדיניות הפרטיות",
    "Header logo" : "לוגו כותרת",
    "Upload new header logo" : "העלאת לוגו כותרת",
    "Favicon" : "סמל כותרת",
    "Upload new favicon" : "העלאת סמל כותרת חדש",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "יש להתקין את הרחבת ה־PHP של Imagemagick עם תמיכה בתמונות SVG כדי לייצר תמונות מועדפים אוטומטיות על בסיס הלוגו שהועלה והצבע.",
    "You are already using a custom theme" : "כבר החלת ערכת עיצוב בהתאמה אישית",
    "reset to default" : "איפוס לבררת מחדל",
    "Web address" : "כתובת",
    "Web address https://…" : "כתובת https://…‎",
    "There is no error, the file uploaded with success" : "אין אף תקלה, הקובץ הועלה בהצלחה",
    "The uploaded file was only partially uploaded" : "הקובץ הועלה באופן חלקי בלבד",
    "Failed to write file to disk." : "הכתיבה לכונן נכשלה.",
    "A PHP extension stopped the file upload." : "הרחבת PHP עצרה את העלאת הקובץ."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
